@@ -1,6 +1,6 @@
 /*
     This file is part of jwhois
-    Copyright (C) 1999  Free Software Foundation, Inc.
+    Copyright (C) 2001-2002  Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,9 +20,12 @@
 #ifndef _UTILS_H
 #define _UTILS_H
 
-char *get_whois_server_domain_path(char *hostname);
-char *get_whois_server_option(char *hostname, char *key);
+char *get_whois_server_domain_path(const char *hostname);
+char *get_whois_server_option(const char *hostname, const char *key);
+char *create_string(const char *fmt, ...);
+int split_host_from_query(struct s_whois_query *wq);
+int make_connect(const char *, int);
+int add_text_to_buffer(char **, const char *);
+
 
 #endif
-
-
